pub struct HttpError<'dispatch> { /* private fields */ }Expand description
The failure an application error handler is asked to rewrite.
Implementations
Sourceimpl HttpError<'_>
impl HttpError<'_>
Sourcepub const fn source(&self) -> HttpErrorSource
pub const fn source(&self) -> HttpErrorSource
Origin of this failure.
Sourcepub const fn status(&self) -> u16
pub const fn status(&self) -> u16
Status of the response dispatch built before any handler ran.
Sourcepub const fn method(&self) -> HttpMethod
pub const fn method(&self) -> HttpMethod
Request method.
Sourcepub const fn operation(&self) -> Option<&OperationDescriptor>
pub const fn operation(&self) -> Option<&OperationDescriptor>
Operation the router selected, when the failure happened after routing.